define(["require", "exports", "react", "./useConst"], function (require, exports, React, useConst_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Hook to store a value and generate callbacks for setting the value to true or false.
     * The identity of the callbacks will always stay the same.
     *
     * @param initialState - Initial value
     * @returns Array with the current value and an object containing the updater callbacks.
     */
    function useBoolean(initialState) {
        var _a = React.useState(initialState), value = _a[0], setValue = _a[1];
        // Storing the value in a ref is redundant but allows the `toggle` callback to have a
        // constant identity, which overall is probably better for consumers' perf.
        var valueRef = React.useRef(value);
        var setTrue = useConst_1.useConst(function () { return function () {
            setValue(true);
            valueRef.current = true;
        }; });
        var setFalse = useConst_1.useConst(function () { return function () {
            setValue(false);
            valueRef.current = false;
        }; });
        var toggle = useConst_1.useConst(function () { return function () { return (valueRef.current ? setFalse() : setTrue()); }; });
        return [value, { setTrue: setTrue, setFalse: setFalse, toggle: toggle }];
    }
    exports.useBoolean = useBoolean;
});
//# sourceMappingURL=useBoolean.js.map